# Platforms vs. Apps

> **Healthcare platforms do much more than apps.**

Many claim to have built platforms, but few deliver on the promises. Below are several key differences between platforms and apps, as well as examples to help you or your organization understand why choosing a platform instead of an app is a safe, robust, and effective choice.

---

## ① A platform solves broad long-term  problems for many interconnected stakeholders.

Apps focus on quickly solving individual problems for a limited group of stakeholders.

The LAMP Platform is flexible and provides novel solutions for research studies, personal care, and clinical care across medical specialties such as psychiatry, neurology, anesthesiology, and cardiology.

Dr. T is a researcher using the LAMP Platform to track longitudinal symptoms in schizophrenia.

Dr. M is a clinician using the LAMP Platform in inpatient cardiology to monitor quality of care.

PS is a patient independently using the LAMP Platform to track lived experiences and share them with family and trusted peers.

---

## ② A platform is flexible and customizable.

Apps have fixed content that can’t be modified to fit unique requirements.

With the LAMP Platform, create activities such as check-in or symptom surveys with your own questions. Change the difficulty or settings of any cognitive assessments you would like to try. Schedule reminders for activities or groups of activities at certain times of the day/week. Track engagement with scheduled activities or change schedules dynamically.

Dr. T designs surveys to track and monitor symptoms of psychosis in his study participants.

Dr. M has her patients take several cognitive assessments a week and a quality survey to understand how they feel about their care. 

When PS wakes up, he receives a reminder to read a new tip from his weekly category and to start his day off with a breathing exercise. 

---

## ③ A platform is accessible on multiple devices, in multiple languages, and by multiple users.

Apps are designed only for a single user on their personal devices. 

Use any modern browser (IE11+, Chrome, Safari, Firefox), smartphone, or wearable device to access the LAMP Platform. Add teammates of part of a care team or multiple trusted peers/family as a patient, where each user can customize their own experience individually. Visualize and export data automatically in common formats (CSV, JSON) or in code (JS, Py, R).

Both PS and Dr. T’s study participants also use a wearable device to track sleep activity and step count each day.

Dr. T and Dr. M both use their desktop browsers to access the dashboard, but their study participants and patients use the app on their smartphones.

PS’s mother lives in India and doesn’t speak English, but still helps keep track of his symptoms and how active he is each day as a student in California.

---

## ④ A platform securely enables data interoperability and extensibility.

Apps manage user content in ‘data silos’ on an individual’s smartphone without external access.

The LAMP Platform uses a simple data vocabulary that can be easily understood, and provides tools to manipulate and interpret data in popular programming and data analytics languages.

Dr. T’s research fellows use their lab’s preferred data analytics software to condense and statistically interpret data, and can provide the source code alongside manuscripts for other research groups to reproduce their work.

Dr. M’s hospital IT department builds a completely new dashboard just for their cardiology department that connects the LAMP Platform with their EHR, allowing ___________.

PS can customize his experience using the LAMP Platform without any coding experience and synchronizes his Fitbit band’s data. 

---

## ⑤ A platform integrates into existing hospital or clinic infrastructure.

Apps are designed to work in a limited ‘sandbox’ on an individual’s smartphone.

The LAMP Platform can be configured to any organization’s unique needs and can be remotely provisioned and managed alongside medical systems already in use.

Dr. T’s IRB also signs off on the LAMP Platform, knowing that their organization has complete control over how the systems work and where the data goes.

Dr. M’s hospital IT department and privacy office manage the LAMP Platform for her, so she doesn’t have to think about security and privacy, technical issues, or other concerns when working with patients.

PS uses the publicly available LAMP Platform instance and uses a smartphone app with his Apple Watch fitness tracker, but shares access to the web dashboard with his mother and PCP, who can save shared data to PS’s health records.

---

## ⑥ A platform engages the care team through interactive clinical decision support.

Apps are functionally limited and cannot offer multifaceted adaptive responses and interventions.

The LAMP Platform longitudinally follows clients across contexts and provides composable building blocks to design real-time visualizations, monitoring systems, and clinical alerts.

Dr. T configures the LAMP Platform to automatically generate new statistical visualizations across their entire study whenever participants play a cognitive test or engage in physical activity.

Dr. M configures the LAMP Platform to send alerts when patients respond to questionnaires negatively, so the patient’s care team can respond quickly and effectively in case of emergency. 

When PS responds to the LAMP Platform that he hasn’t been feeling well, his mother receives a text message and knows to call him and his therapist.

---

- Automations Use-case

    > Using the Automations framework in the LAMP Platform is like the difference between running an entire chemistry lab to individually process your patient blood tests versus having an in-house medical diagnostics facility that simply provides profile reports for every processed blood sample.

    It’s the integrated digital ‘medical diagnostics facility’ for the terabytes of data that you quickly capture using the LAMP Platform — and you can quickly get started with any of our pre-built templates, or customize every aspect of the processing pipeline for your unique needs.
